ITelephonyNumber Interface

Definition

Namespace: DataStandardizer.Communication

The root abstraction for any telephony number, exposing the raw numeric value of the whole number.

public interface ITelephonyNumber

Properties

Property Signature Notes
Number ulong Number { get; } The numeric value of the whole number.

Applies to

Targets netstandard1.0, netstandard2.0, net8.0, and net10.0.

See also

</content>


This site uses Just the Docs, a documentation theme for Jekyll.