ItuE164AssignedCountryCodesForTrials Enum

Definition

Namespace: DataStandardizer.Communication.E164

The ITU E.164 country codes assigned for trials. Used as the country-code argument of ItuE164InternationalNumber.CreateNumberForTrial.

public enum ItuE164AssignedCountryCodesForTrials : ushort

Fields

Field Value Description
SharedCode 991 Trial of a proposed new international telecommunication public correspondence service.

Applies to

Targets netstandard1.0, netstandard2.0, net8.0, and net10.0.

See also

</content>


This site uses Just the Docs, a documentation theme for Jekyll.