ItuE164AssignedTrialIdentificationCodesForTrials Enum

Definition

Namespace: DataStandardizer.Communication.E164

The ITU E.164 trial identification codes assigned within trial codes. Used as the trial-identification-code argument of ItuE164InternationalNumber.CreateNumberForTrial.

public enum ItuE164AssignedTrialIdentificationCodesForTrials : byte

Remarks

This is a generated enumeration of the codes shared between countries (up to date as at 2025-01-24). No trial identification codes are currently assigned, so the enumeration defines no members.

Fields

This enumeration currently defines no members.

Applies to

Targets netstandard1.0, netstandard2.0, net8.0, and net10.0.

See also

</content>


This site uses Just the Docs, a documentation theme for Jekyll.