ItuE164AssignedGroupIdentificationCodesForGroupsOfCountries Enum
Definition
Namespace: DataStandardizer.Communication.E164
The ITU E.164 group identification codes assigned within group-of-countries codes. Used as the group-identification-code argument of ItuE164InternationalNumber.CreateNumberForGroupOfCountries.
public enum ItuE164AssignedGroupIdentificationCodesForGroupsOfCountries : byte
Remarks
This is a generated enumeration of the codes shared between countries (up to date as at 2025-01-24). No group identification codes are currently assigned, so the enumeration defines no members.
Fields
This enumeration currently defines no members.
Applies to
Targets netstandard1.0, netstandard2.0, net8.0, and net10.0.
See also
- ItuE164InternationalNumber
- IItuE164InternationalNumberForGroupsOfCountries
- ItuE164AssignedCountryCodesForGroupsOfCountries
- Communication API reference
</content>